# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ClientApp(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ClientApp - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'integration_type': 'IntegrationType',
            'notes': 'str',
            'intended_state': 'str',
            'config': 'ClientAppConfigurationInfo',
            'reported_state': 'IntegrationStatusInfo',
            'attributes': 'dict(str, str)',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'integration_type': 'integrationType',
            'notes': 'notes',
            'intended_state': 'intendedState',
            'config': 'config',
            'reported_state': 'reportedState',
            'attributes': 'attributes',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._integration_type = None
        self._notes = None
        self._intended_state = None
        self._config = None
        self._reported_state = None
        self._attributes = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ClientApp.
        The globally unique identifier for the object.

        :return: The id of this ClientApp.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ClientApp.
        The globally unique identifier for the object.

        :param id: The id of this ClientApp.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ClientApp.
        The name of the integration, used to distinguish this integration from others of the same type.

        :return: The name of this ClientApp.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ClientApp.
        The name of the integration, used to distinguish this integration from others of the same type.

        :param name: The name of this ClientApp.
        :type: str
        """
        
        self._name = name

    @property
    def integration_type(self):
        """
        Gets the integration_type of this ClientApp.
        Type of the integration

        :return: The integration_type of this ClientApp.
        :rtype: IntegrationType
        """
        return self._integration_type

    @integration_type.setter
    def integration_type(self, integration_type):
        """
        Sets the integration_type of this ClientApp.
        Type of the integration

        :param integration_type: The integration_type of this ClientApp.
        :type: IntegrationType
        """
        
        self._integration_type = integration_type

    @property
    def notes(self):
        """
        Gets the notes of this ClientApp.
        Notes about the integration.

        :return: The notes of this ClientApp.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """
        Sets the notes of this ClientApp.
        Notes about the integration.

        :param notes: The notes of this ClientApp.
        :type: str
        """
        
        self._notes = notes

    @property
    def intended_state(self):
        """
        Gets the intended_state of this ClientApp.
        Configured state of the integration.

        :return: The intended_state of this ClientApp.
        :rtype: str
        """
        return self._intended_state

    @intended_state.setter
    def intended_state(self, intended_state):
        """
        Sets the intended_state of this ClientApp.
        Configured state of the integration.

        :param intended_state: The intended_state of this ClientApp.
        :type: str
        """
        allowed_values = ["ENABLED", "DISABLED", "DELETED"]
        if intended_state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for intended_state -> " + intended_state)
            self._intended_state = "outdated_sdk_version"
        else:
            self._intended_state = intended_state

    @property
    def config(self):
        """
        Gets the config of this ClientApp.
        Configuration information for the integration.

        :return: The config of this ClientApp.
        :rtype: ClientAppConfigurationInfo
        """
        return self._config

    @config.setter
    def config(self, config):
        """
        Sets the config of this ClientApp.
        Configuration information for the integration.

        :param config: The config of this ClientApp.
        :type: ClientAppConfigurationInfo
        """
        
        self._config = config

    @property
    def reported_state(self):
        """
        Gets the reported_state of this ClientApp.
        Last reported status of the integration.

        :return: The reported_state of this ClientApp.
        :rtype: IntegrationStatusInfo
        """
        return self._reported_state

    @reported_state.setter
    def reported_state(self, reported_state):
        """
        Sets the reported_state of this ClientApp.
        Last reported status of the integration.

        :param reported_state: The reported_state of this ClientApp.
        :type: IntegrationStatusInfo
        """
        
        self._reported_state = reported_state

    @property
    def attributes(self):
        """
        Gets the attributes of this ClientApp.
        Read-only attributes for the integration.

        :return: The attributes of this ClientApp.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this ClientApp.
        Read-only attributes for the integration.

        :param attributes: The attributes of this ClientApp.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ClientApp.
        The URI for this object

        :return: The self_uri of this ClientApp.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ClientApp.
        The URI for this object

        :param self_uri: The self_uri of this ClientApp.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class MessagingSticker(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        MessagingSticker - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'provider_sticker_id': 'int',
            'provider_package_id': 'int',
            'package_name': 'str',
            'messenger_type': 'str',
            'sticker_type': 'str',
            'provider_version': 'int',
            'uri_location': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'provider_sticker_id': 'providerStickerId',
            'provider_package_id': 'providerPackageId',
            'package_name': 'packageName',
            'messenger_type': 'messengerType',
            'sticker_type': 'stickerType',
            'provider_version': 'providerVersion',
            'uri_location': 'uriLocation',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._provider_sticker_id = None
        self._provider_package_id = None
        self._package_name = None
        self._messenger_type = None
        self._sticker_type = None
        self._provider_version = None
        self._uri_location = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this MessagingSticker.
        The globally unique identifier for the object.

        :return: The id of this MessagingSticker.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this MessagingSticker.
        The globally unique identifier for the object.

        :param id: The id of this MessagingSticker.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this MessagingSticker.


        :return: The name of this MessagingSticker.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this MessagingSticker.


        :param name: The name of this MessagingSticker.
        :type: str
        """
        
        self._name = name

    @property
    def provider_sticker_id(self):
        """
        Gets the provider_sticker_id of this MessagingSticker.
        The sticker Id of the sticker, assigned by the sticker provider.

        :return: The provider_sticker_id of this MessagingSticker.
        :rtype: int
        """
        return self._provider_sticker_id

    @provider_sticker_id.setter
    def provider_sticker_id(self, provider_sticker_id):
        """
        Sets the provider_sticker_id of this MessagingSticker.
        The sticker Id of the sticker, assigned by the sticker provider.

        :param provider_sticker_id: The provider_sticker_id of this MessagingSticker.
        :type: int
        """
        
        self._provider_sticker_id = provider_sticker_id

    @property
    def provider_package_id(self):
        """
        Gets the provider_package_id of this MessagingSticker.
        The package Id of the sticker, assigned by the sticker provider.

        :return: The provider_package_id of this MessagingSticker.
        :rtype: int
        """
        return self._provider_package_id

    @provider_package_id.setter
    def provider_package_id(self, provider_package_id):
        """
        Sets the provider_package_id of this MessagingSticker.
        The package Id of the sticker, assigned by the sticker provider.

        :param provider_package_id: The provider_package_id of this MessagingSticker.
        :type: int
        """
        
        self._provider_package_id = provider_package_id

    @property
    def package_name(self):
        """
        Gets the package_name of this MessagingSticker.
        The package name of the sticker, assigned by the sticker provider.

        :return: The package_name of this MessagingSticker.
        :rtype: str
        """
        return self._package_name

    @package_name.setter
    def package_name(self, package_name):
        """
        Sets the package_name of this MessagingSticker.
        The package name of the sticker, assigned by the sticker provider.

        :param package_name: The package_name of this MessagingSticker.
        :type: str
        """
        
        self._package_name = package_name

    @property
    def messenger_type(self):
        """
        Gets the messenger_type of this MessagingSticker.
        The type of the messenger provider.

        :return: The messenger_type of this MessagingSticker.
        :rtype: str
        """
        return self._messenger_type

    @messenger_type.setter
    def messenger_type(self, messenger_type):
        """
        Sets the messenger_type of this MessagingSticker.
        The type of the messenger provider.

        :param messenger_type: The messenger_type of this MessagingSticker.
        :type: str
        """
        allowed_values = ["sms", "facebook", "twitter", "line", "whatsapp", "webmessaging", "open"]
        if messenger_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for messenger_type -> " + messenger_type)
            self._messenger_type = "outdated_sdk_version"
        else:
            self._messenger_type = messenger_type

    @property
    def sticker_type(self):
        """
        Gets the sticker_type of this MessagingSticker.
        The type of the sticker.

        :return: The sticker_type of this MessagingSticker.
        :rtype: str
        """
        return self._sticker_type

    @sticker_type.setter
    def sticker_type(self, sticker_type):
        """
        Sets the sticker_type of this MessagingSticker.
        The type of the sticker.

        :param sticker_type: The sticker_type of this MessagingSticker.
        :type: str
        """
        allowed_values = ["standard", "free", "paid"]
        if sticker_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for sticker_type -> " + sticker_type)
            self._sticker_type = "outdated_sdk_version"
        else:
            self._sticker_type = sticker_type

    @property
    def provider_version(self):
        """
        Gets the provider_version of this MessagingSticker.
        The version of the sticker, assigned by the provider.

        :return: The provider_version of this MessagingSticker.
        :rtype: int
        """
        return self._provider_version

    @provider_version.setter
    def provider_version(self, provider_version):
        """
        Sets the provider_version of this MessagingSticker.
        The version of the sticker, assigned by the provider.

        :param provider_version: The provider_version of this MessagingSticker.
        :type: int
        """
        
        self._provider_version = provider_version

    @property
    def uri_location(self):
        """
        Gets the uri_location of this MessagingSticker.


        :return: The uri_location of this MessagingSticker.
        :rtype: str
        """
        return self._uri_location

    @uri_location.setter
    def uri_location(self, uri_location):
        """
        Sets the uri_location of this MessagingSticker.


        :param uri_location: The uri_location of this MessagingSticker.
        :type: str
        """
        
        self._uri_location = uri_location

    @property
    def self_uri(self):
        """
        Gets the self_uri of this MessagingSticker.
        The URI for this object

        :return: The self_uri of this MessagingSticker.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this MessagingSticker.
        The URI for this object

        :param self_uri: The self_uri of this MessagingSticker.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AuditRealtimeQueryRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AuditRealtimeQueryRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'interval': 'str',
            'service_name': 'str',
            'filters': 'list[AuditQueryFilter]',
            'sort': 'list[AuditQuerySort]',
            'page_number': 'int',
            'page_size': 'int'
        }

        self.attribute_map = {
            'interval': 'interval',
            'service_name': 'serviceName',
            'filters': 'filters',
            'sort': 'sort',
            'page_number': 'pageNumber',
            'page_size': 'pageSize'
        }

        self._interval = None
        self._service_name = None
        self._filters = None
        self._sort = None
        self._page_number = None
        self._page_size = None

    @property
    def interval(self):
        """
        Gets the interval of this AuditRealtimeQueryRequest.
        Date and time range of data to query. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :return: The interval of this AuditRealtimeQueryRequest.
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """
        Sets the interval of this AuditRealtimeQueryRequest.
        Date and time range of data to query. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :param interval: The interval of this AuditRealtimeQueryRequest.
        :type: str
        """
        
        self._interval = interval

    @property
    def service_name(self):
        """
        Gets the service_name of this AuditRealtimeQueryRequest.
        Name of the service to query audits for.

        :return: The service_name of this AuditRealtimeQueryRequest.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this AuditRealtimeQueryRequest.
        Name of the service to query audits for.

        :param service_name: The service_name of this AuditRealtimeQueryRequest.
        :type: str
        """
        allowed_values = ["Architect", "ContactCenter", "ContentManagement", "PeoplePermissions", "Presence", "Quality", "LanguageUnderstanding", "TopicsDefinitions", "PredictiveEngagement", "WorkforceManagement", "Triggers", "ResponseManagement", "Groups", "Telephony", "Outbound", "SpeechAndTextAnalytics", "Routing"]
        if service_name.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for service_name -> " + service_name)
            self._service_name = "outdated_sdk_version"
        else:
            self._service_name = service_name

    @property
    def filters(self):
        """
        Gets the filters of this AuditRealtimeQueryRequest.
        Additional filters for the query.

        :return: The filters of this AuditRealtimeQueryRequest.
        :rtype: list[AuditQueryFilter]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """
        Sets the filters of this AuditRealtimeQueryRequest.
        Additional filters for the query.

        :param filters: The filters of this AuditRealtimeQueryRequest.
        :type: list[AuditQueryFilter]
        """
        
        self._filters = filters

    @property
    def sort(self):
        """
        Gets the sort of this AuditRealtimeQueryRequest.
        Sort parameter for the query.

        :return: The sort of this AuditRealtimeQueryRequest.
        :rtype: list[AuditQuerySort]
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """
        Sets the sort of this AuditRealtimeQueryRequest.
        Sort parameter for the query.

        :param sort: The sort of this AuditRealtimeQueryRequest.
        :type: list[AuditQuerySort]
        """
        
        self._sort = sort

    @property
    def page_number(self):
        """
        Gets the page_number of this AuditRealtimeQueryRequest.
        Page number

        :return: The page_number of this AuditRealtimeQueryRequest.
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """
        Sets the page_number of this AuditRealtimeQueryRequest.
        Page number

        :param page_number: The page_number of this AuditRealtimeQueryRequest.
        :type: int
        """
        
        self._page_number = page_number

    @property
    def page_size(self):
        """
        Gets the page_size of this AuditRealtimeQueryRequest.
        Page size

        :return: The page_size of this AuditRealtimeQueryRequest.
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """
        Sets the page_size of this AuditRealtimeQueryRequest.
        Page size

        :param page_size: The page_size of this AuditRealtimeQueryRequest.
        :type: int
        """
        
        self._page_size = page_size

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AnalyticsUserPresenceRecord(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AnalyticsUserPresenceRecord - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'start_time': 'datetime',
            'end_time': 'datetime',
            'system_presence': 'str',
            'organization_presence_id': 'str'
        }

        self.attribute_map = {
            'start_time': 'startTime',
            'end_time': 'endTime',
            'system_presence': 'systemPresence',
            'organization_presence_id': 'organizationPresenceId'
        }

        self._start_time = None
        self._end_time = None
        self._system_presence = None
        self._organization_presence_id = None

    @property
    def start_time(self):
        """
        Gets the start_time of this AnalyticsUserPresenceRecord.
        The start time of the record. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_time of this AnalyticsUserPresenceRecord.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this AnalyticsUserPresenceRecord.
        The start time of the record. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_time: The start_time of this AnalyticsUserPresenceRecord.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def end_time(self):
        """
        Gets the end_time of this AnalyticsUserPresenceRecord.
        The end time of the record. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The end_time of this AnalyticsUserPresenceRecord.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this AnalyticsUserPresenceRecord.
        The end time of the record. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param end_time: The end_time of this AnalyticsUserPresenceRecord.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def system_presence(self):
        """
        Gets the system_presence of this AnalyticsUserPresenceRecord.
        The user's system presence

        :return: The system_presence of this AnalyticsUserPresenceRecord.
        :rtype: str
        """
        return self._system_presence

    @system_presence.setter
    def system_presence(self, system_presence):
        """
        Sets the system_presence of this AnalyticsUserPresenceRecord.
        The user's system presence

        :param system_presence: The system_presence of this AnalyticsUserPresenceRecord.
        :type: str
        """
        allowed_values = ["AVAILABLE", "AWAY", "BUSY", "OFFLINE", "IDLE", "ON_QUEUE", "MEAL", "TRAINING", "MEETING", "BREAK"]
        if system_presence.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for system_presence -> " + system_presence)
            self._system_presence = "outdated_sdk_version"
        else:
            self._system_presence = system_presence

    @property
    def organization_presence_id(self):
        """
        Gets the organization_presence_id of this AnalyticsUserPresenceRecord.
        The identifier for the user's organization presence

        :return: The organization_presence_id of this AnalyticsUserPresenceRecord.
        :rtype: str
        """
        return self._organization_presence_id

    @organization_presence_id.setter
    def organization_presence_id(self, organization_presence_id):
        """
        Sets the organization_presence_id of this AnalyticsUserPresenceRecord.
        The identifier for the user's organization presence

        :param organization_presence_id: The organization_presence_id of this AnalyticsUserPresenceRecord.
        :type: str
        """
        
        self._organization_presence_id = organization_presence_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AddShiftTradeRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AddShiftTradeRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'schedule_id': 'str',
            'initiating_shift_id': 'str',
            'receiving_user_id': 'str',
            'expiration': 'datetime',
            'acceptable_intervals': 'list[str]'
        }

        self.attribute_map = {
            'schedule_id': 'scheduleId',
            'initiating_shift_id': 'initiatingShiftId',
            'receiving_user_id': 'receivingUserId',
            'expiration': 'expiration',
            'acceptable_intervals': 'acceptableIntervals'
        }

        self._schedule_id = None
        self._initiating_shift_id = None
        self._receiving_user_id = None
        self._expiration = None
        self._acceptable_intervals = None

    @property
    def schedule_id(self):
        """
        Gets the schedule_id of this AddShiftTradeRequest.
        The ID of the schedule to which the initiating and receiving shifts belong

        :return: The schedule_id of this AddShiftTradeRequest.
        :rtype: str
        """
        return self._schedule_id

    @schedule_id.setter
    def schedule_id(self, schedule_id):
        """
        Sets the schedule_id of this AddShiftTradeRequest.
        The ID of the schedule to which the initiating and receiving shifts belong

        :param schedule_id: The schedule_id of this AddShiftTradeRequest.
        :type: str
        """
        
        self._schedule_id = schedule_id

    @property
    def initiating_shift_id(self):
        """
        Gets the initiating_shift_id of this AddShiftTradeRequest.
        The ID of the shift that the initiating user wants to give up

        :return: The initiating_shift_id of this AddShiftTradeRequest.
        :rtype: str
        """
        return self._initiating_shift_id

    @initiating_shift_id.setter
    def initiating_shift_id(self, initiating_shift_id):
        """
        Sets the initiating_shift_id of this AddShiftTradeRequest.
        The ID of the shift that the initiating user wants to give up

        :param initiating_shift_id: The initiating_shift_id of this AddShiftTradeRequest.
        :type: str
        """
        
        self._initiating_shift_id = initiating_shift_id

    @property
    def receiving_user_id(self):
        """
        Gets the receiving_user_id of this AddShiftTradeRequest.
        The ID of the user to whom to send the request (for use in direct trade requests)

        :return: The receiving_user_id of this AddShiftTradeRequest.
        :rtype: str
        """
        return self._receiving_user_id

    @receiving_user_id.setter
    def receiving_user_id(self, receiving_user_id):
        """
        Sets the receiving_user_id of this AddShiftTradeRequest.
        The ID of the user to whom to send the request (for use in direct trade requests)

        :param receiving_user_id: The receiving_user_id of this AddShiftTradeRequest.
        :type: str
        """
        
        self._receiving_user_id = receiving_user_id

    @property
    def expiration(self):
        """
        Gets the expiration of this AddShiftTradeRequest.
        When this shift trade request should expire. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The expiration of this AddShiftTradeRequest.
        :rtype: datetime
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """
        Sets the expiration of this AddShiftTradeRequest.
        When this shift trade request should expire. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param expiration: The expiration of this AddShiftTradeRequest.
        :type: datetime
        """
        
        self._expiration = expiration

    @property
    def acceptable_intervals(self):
        """
        Gets the acceptable_intervals of this AddShiftTradeRequest.


        :return: The acceptable_intervals of this AddShiftTradeRequest.
        :rtype: list[str]
        """
        return self._acceptable_intervals

    @acceptable_intervals.setter
    def acceptable_intervals(self, acceptable_intervals):
        """
        Sets the acceptable_intervals of this AddShiftTradeRequest.


        :param acceptable_intervals: The acceptable_intervals of this AddShiftTradeRequest.
        :type: list[str]
        """
        
        self._acceptable_intervals = acceptable_intervals

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueUserEventTopicQueueMember(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueUserEventTopicQueueMember - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'user': 'QueueUserEventTopicUserReference',
            'queue_id': 'str',
            'joined': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'user': 'user',
            'queue_id': 'queueId',
            'joined': 'joined',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._user = None
        self._queue_id = None
        self._joined = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this QueueUserEventTopicQueueMember.


        :return: The id of this QueueUserEventTopicQueueMember.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueUserEventTopicQueueMember.


        :param id: The id of this QueueUserEventTopicQueueMember.
        :type: str
        """
        
        self._id = id

    @property
    def user(self):
        """
        Gets the user of this QueueUserEventTopicQueueMember.


        :return: The user of this QueueUserEventTopicQueueMember.
        :rtype: QueueUserEventTopicUserReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this QueueUserEventTopicQueueMember.


        :param user: The user of this QueueUserEventTopicQueueMember.
        :type: QueueUserEventTopicUserReference
        """
        
        self._user = user

    @property
    def queue_id(self):
        """
        Gets the queue_id of this QueueUserEventTopicQueueMember.


        :return: The queue_id of this QueueUserEventTopicQueueMember.
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """
        Sets the queue_id of this QueueUserEventTopicQueueMember.


        :param queue_id: The queue_id of this QueueUserEventTopicQueueMember.
        :type: str
        """
        
        self._queue_id = queue_id

    @property
    def joined(self):
        """
        Gets the joined of this QueueUserEventTopicQueueMember.


        :return: The joined of this QueueUserEventTopicQueueMember.
        :rtype: bool
        """
        return self._joined

    @joined.setter
    def joined(self, joined):
        """
        Sets the joined of this QueueUserEventTopicQueueMember.


        :param joined: The joined of this QueueUserEventTopicQueueMember.
        :type: bool
        """
        
        self._joined = joined

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueUserEventTopicQueueMember.


        :return: The additional_properties of this QueueUserEventTopicQueueMember.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueUserEventTopicQueueMember.


        :param additional_properties: The additional_properties of this QueueUserEventTopicQueueMember.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DomainNetworkAddress(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DomainNetworkAddress - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'type': 'str',
            'address': 'str',
            'persistent': 'bool',
            'family': 'int'
        }

        self.attribute_map = {
            'type': 'type',
            'address': 'address',
            'persistent': 'persistent',
            'family': 'family'
        }

        self._type = None
        self._address = None
        self._persistent = None
        self._family = None

    @property
    def type(self):
        """
        Gets the type of this DomainNetworkAddress.
        The type of address.

        :return: The type of this DomainNetworkAddress.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this DomainNetworkAddress.
        The type of address.

        :param type: The type of this DomainNetworkAddress.
        :type: str
        """
        allowed_values = ["ip", "dns", "gateway", "tdm"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def address(self):
        """
        Gets the address of this DomainNetworkAddress.
        An IPv4 or IPv6 IP address. When specifying an address of type \"ip\", use CIDR format for the subnet mask.

        :return: The address of this DomainNetworkAddress.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this DomainNetworkAddress.
        An IPv4 or IPv6 IP address. When specifying an address of type \"ip\", use CIDR format for the subnet mask.

        :param address: The address of this DomainNetworkAddress.
        :type: str
        """
        
        self._address = address

    @property
    def persistent(self):
        """
        Gets the persistent of this DomainNetworkAddress.
        True if this address will persist on Edge restart.  Addresses assigned by DHCP will be returned as false.

        :return: The persistent of this DomainNetworkAddress.
        :rtype: bool
        """
        return self._persistent

    @persistent.setter
    def persistent(self, persistent):
        """
        Sets the persistent of this DomainNetworkAddress.
        True if this address will persist on Edge restart.  Addresses assigned by DHCP will be returned as false.

        :param persistent: The persistent of this DomainNetworkAddress.
        :type: bool
        """
        
        self._persistent = persistent

    @property
    def family(self):
        """
        Gets the family of this DomainNetworkAddress.
        The address family for this address.

        :return: The family of this DomainNetworkAddress.
        :rtype: int
        """
        return self._family

    @family.setter
    def family(self, family):
        """
        Sets the family of this DomainNetworkAddress.
        The address family for this address.

        :param family: The family of this DomainNetworkAddress.
        :type: int
        """
        allowed_values = ["2", "23"]
        if family.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for family -> " + family)
            self._family = "outdated_sdk_version"
        else:
            self._family = family

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WidgetDeployment(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WidgetDeployment - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'authentication_required': 'bool',
            'disabled': 'bool',
            'flow': 'DomainEntityRef',
            'allowed_domains': 'list[str]',
            'client_type': 'str',
            'client_config': 'WidgetClientConfig',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'authentication_required': 'authenticationRequired',
            'disabled': 'disabled',
            'flow': 'flow',
            'allowed_domains': 'allowedDomains',
            'client_type': 'clientType',
            'client_config': 'clientConfig',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._authentication_required = None
        self._disabled = None
        self._flow = None
        self._allowed_domains = None
        self._client_type = None
        self._client_config = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this WidgetDeployment.
        The globally unique identifier for the object.

        :return: The id of this WidgetDeployment.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WidgetDeployment.
        The globally unique identifier for the object.

        :param id: The id of this WidgetDeployment.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this WidgetDeployment.


        :return: The name of this WidgetDeployment.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this WidgetDeployment.


        :param name: The name of this WidgetDeployment.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this WidgetDeployment.
        A human-readable description of this Deployment.

        :return: The description of this WidgetDeployment.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this WidgetDeployment.
        A human-readable description of this Deployment.

        :param description: The description of this WidgetDeployment.
        :type: str
        """
        
        self._description = description

    @property
    def authentication_required(self):
        """
        Gets the authentication_required of this WidgetDeployment.
        When true, the customer members starting a chat must be authenticated by supplying their JWT to the create operation.

        :return: The authentication_required of this WidgetDeployment.
        :rtype: bool
        """
        return self._authentication_required

    @authentication_required.setter
    def authentication_required(self, authentication_required):
        """
        Sets the authentication_required of this WidgetDeployment.
        When true, the customer members starting a chat must be authenticated by supplying their JWT to the create operation.

        :param authentication_required: The authentication_required of this WidgetDeployment.
        :type: bool
        """
        
        self._authentication_required = authentication_required

    @property
    def disabled(self):
        """
        Gets the disabled of this WidgetDeployment.
        When true, all create chat operations using this Deployment will be rejected.

        :return: The disabled of this WidgetDeployment.
        :rtype: bool
        """
        return self._disabled

    @disabled.setter
    def disabled(self, disabled):
        """
        Sets the disabled of this WidgetDeployment.
        When true, all create chat operations using this Deployment will be rejected.

        :param disabled: The disabled of this WidgetDeployment.
        :type: bool
        """
        
        self._disabled = disabled

    @property
    def flow(self):
        """
        Gets the flow of this WidgetDeployment.
        The URI of the Inbound Chat Flow to run when new chats are initiated under this Deployment.

        :return: The flow of this WidgetDeployment.
        :rtype: DomainEntityRef
        """
        return self._flow

    @flow.setter
    def flow(self, flow):
        """
        Sets the flow of this WidgetDeployment.
        The URI of the Inbound Chat Flow to run when new chats are initiated under this Deployment.

        :param flow: The flow of this WidgetDeployment.
        :type: DomainEntityRef
        """
        
        self._flow = flow

    @property
    def allowed_domains(self):
        """
        Gets the allowed_domains of this WidgetDeployment.
        The list of domains that are approved to use this Deployment; the list will be added to CORS headers for ease of web use.

        :return: The allowed_domains of this WidgetDeployment.
        :rtype: list[str]
        """
        return self._allowed_domains

    @allowed_domains.setter
    def allowed_domains(self, allowed_domains):
        """
        Sets the allowed_domains of this WidgetDeployment.
        The list of domains that are approved to use this Deployment; the list will be added to CORS headers for ease of web use.

        :param allowed_domains: The allowed_domains of this WidgetDeployment.
        :type: list[str]
        """
        
        self._allowed_domains = allowed_domains

    @property
    def client_type(self):
        """
        Gets the client_type of this WidgetDeployment.
        The type of display widget for which this Deployment is configured, which controls the administrator settings shown.

        :return: The client_type of this WidgetDeployment.
        :rtype: str
        """
        return self._client_type

    @client_type.setter
    def client_type(self, client_type):
        """
        Sets the client_type of this WidgetDeployment.
        The type of display widget for which this Deployment is configured, which controls the administrator settings shown.

        :param client_type: The client_type of this WidgetDeployment.
        :type: str
        """
        allowed_values = ["v1", "v2", "v1-http", "third-party"]
        if client_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for client_type -> " + client_type)
            self._client_type = "outdated_sdk_version"
        else:
            self._client_type = client_type

    @property
    def client_config(self):
        """
        Gets the client_config of this WidgetDeployment.
        The client configuration options that should be made available to the clients of this Deployment.

        :return: The client_config of this WidgetDeployment.
        :rtype: WidgetClientConfig
        """
        return self._client_config

    @client_config.setter
    def client_config(self, client_config):
        """
        Sets the client_config of this WidgetDeployment.
        The client configuration options that should be made available to the clients of this Deployment.

        :param client_config: The client_config of this WidgetDeployment.
        :type: WidgetClientConfig
        """
        
        self._client_config = client_config

    @property
    def self_uri(self):
        """
        Gets the self_uri of this WidgetDeployment.
        The URI for this object

        :return: The self_uri of this WidgetDeployment.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this WidgetDeployment.
        The URI for this object

        :param self_uri: The self_uri of this WidgetDeployment.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class OutcomeProbabilityCondition(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        OutcomeProbabilityCondition - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'outcome_id': 'str',
            'maximum_probability': 'float',
            'probability': 'float'
        }

        self.attribute_map = {
            'outcome_id': 'outcomeId',
            'maximum_probability': 'maximumProbability',
            'probability': 'probability'
        }

        self._outcome_id = None
        self._maximum_probability = None
        self._probability = None

    @property
    def outcome_id(self):
        """
        Gets the outcome_id of this OutcomeProbabilityCondition.
        The outcome ID.

        :return: The outcome_id of this OutcomeProbabilityCondition.
        :rtype: str
        """
        return self._outcome_id

    @outcome_id.setter
    def outcome_id(self, outcome_id):
        """
        Sets the outcome_id of this OutcomeProbabilityCondition.
        The outcome ID.

        :param outcome_id: The outcome_id of this OutcomeProbabilityCondition.
        :type: str
        """
        
        self._outcome_id = outcome_id

    @property
    def maximum_probability(self):
        """
        Gets the maximum_probability of this OutcomeProbabilityCondition.
        Probability value for the selected outcome at or above which the action map will trigger.

        :return: The maximum_probability of this OutcomeProbabilityCondition.
        :rtype: float
        """
        return self._maximum_probability

    @maximum_probability.setter
    def maximum_probability(self, maximum_probability):
        """
        Sets the maximum_probability of this OutcomeProbabilityCondition.
        Probability value for the selected outcome at or above which the action map will trigger.

        :param maximum_probability: The maximum_probability of this OutcomeProbabilityCondition.
        :type: float
        """
        
        self._maximum_probability = maximum_probability

    @property
    def probability(self):
        """
        Gets the probability of this OutcomeProbabilityCondition.
        Additional probability condition, where if set, the action map will trigger if the current outcome probability is lower or equal to the value.

        :return: The probability of this OutcomeProbabilityCondition.
        :rtype: float
        """
        return self._probability

    @probability.setter
    def probability(self, probability):
        """
        Sets the probability of this OutcomeProbabilityCondition.
        Additional probability condition, where if set, the action map will trigger if the current outcome probability is lower or equal to the value.

        :param probability: The probability of this OutcomeProbabilityCondition.
        :type: float
        """
        
        self._probability = probability

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class VoicemailMailboxInfo(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        VoicemailMailboxInfo - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'usage_size_bytes': 'int',
            'total_count': 'int',
            'unread_count': 'int',
            'deleted_count': 'int',
            'created_date': 'datetime',
            'modified_date': 'datetime'
        }

        self.attribute_map = {
            'usage_size_bytes': 'usageSizeBytes',
            'total_count': 'totalCount',
            'unread_count': 'unreadCount',
            'deleted_count': 'deletedCount',
            'created_date': 'createdDate',
            'modified_date': 'modifiedDate'
        }

        self._usage_size_bytes = None
        self._total_count = None
        self._unread_count = None
        self._deleted_count = None
        self._created_date = None
        self._modified_date = None

    @property
    def usage_size_bytes(self):
        """
        Gets the usage_size_bytes of this VoicemailMailboxInfo.
        The total number of bytes for all voicemail message audio recordings

        :return: The usage_size_bytes of this VoicemailMailboxInfo.
        :rtype: int
        """
        return self._usage_size_bytes

    @usage_size_bytes.setter
    def usage_size_bytes(self, usage_size_bytes):
        """
        Sets the usage_size_bytes of this VoicemailMailboxInfo.
        The total number of bytes for all voicemail message audio recordings

        :param usage_size_bytes: The usage_size_bytes of this VoicemailMailboxInfo.
        :type: int
        """
        
        self._usage_size_bytes = usage_size_bytes

    @property
    def total_count(self):
        """
        Gets the total_count of this VoicemailMailboxInfo.
        The total number of voicemail messages

        :return: The total_count of this VoicemailMailboxInfo.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """
        Sets the total_count of this VoicemailMailboxInfo.
        The total number of voicemail messages

        :param total_count: The total_count of this VoicemailMailboxInfo.
        :type: int
        """
        
        self._total_count = total_count

    @property
    def unread_count(self):
        """
        Gets the unread_count of this VoicemailMailboxInfo.
        The total number of voicemail messages marked as unread

        :return: The unread_count of this VoicemailMailboxInfo.
        :rtype: int
        """
        return self._unread_count

    @unread_count.setter
    def unread_count(self, unread_count):
        """
        Sets the unread_count of this VoicemailMailboxInfo.
        The total number of voicemail messages marked as unread

        :param unread_count: The unread_count of this VoicemailMailboxInfo.
        :type: int
        """
        
        self._unread_count = unread_count

    @property
    def deleted_count(self):
        """
        Gets the deleted_count of this VoicemailMailboxInfo.
        The total number of voicemail messages marked as deleted

        :return: The deleted_count of this VoicemailMailboxInfo.
        :rtype: int
        """
        return self._deleted_count

    @deleted_count.setter
    def deleted_count(self, deleted_count):
        """
        Sets the deleted_count of this VoicemailMailboxInfo.
        The total number of voicemail messages marked as deleted

        :param deleted_count: The deleted_count of this VoicemailMailboxInfo.
        :type: int
        """
        
        self._deleted_count = deleted_count

    @property
    def created_date(self):
        """
        Gets the created_date of this VoicemailMailboxInfo.
        The date of the oldest voicemail message. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The created_date of this VoicemailMailboxInfo.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this VoicemailMailboxInfo.
        The date of the oldest voicemail message. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param created_date: The created_date of this VoicemailMailboxInfo.
        :type: datetime
        """
        
        self._created_date = created_date

    @property
    def modified_date(self):
        """
        Gets the modified_date of this VoicemailMailboxInfo.
        The date of the most recent voicemail message. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The modified_date of this VoicemailMailboxInfo.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this VoicemailMailboxInfo.
        The date of the most recent voicemail message. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param modified_date: The modified_date of this VoicemailMailboxInfo.
        :type: datetime
        """
        
        self._modified_date = modified_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class UserBestPointsItem(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UserBestPointsItem - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'granularity_type': 'str',
            'points': 'int',
            'date_start_workday': 'date',
            'date_end_workday': 'date',
            'rank': 'int'
        }

        self.attribute_map = {
            'granularity_type': 'granularityType',
            'points': 'points',
            'date_start_workday': 'dateStartWorkday',
            'date_end_workday': 'dateEndWorkday',
            'rank': 'rank'
        }

        self._granularity_type = None
        self._points = None
        self._date_start_workday = None
        self._date_end_workday = None
        self._rank = None

    @property
    def granularity_type(self):
        """
        Gets the granularity_type of this UserBestPointsItem.
        Best points aggregation interval granularity

        :return: The granularity_type of this UserBestPointsItem.
        :rtype: str
        """
        return self._granularity_type

    @granularity_type.setter
    def granularity_type(self, granularity_type):
        """
        Sets the granularity_type of this UserBestPointsItem.
        Best points aggregation interval granularity

        :param granularity_type: The granularity_type of this UserBestPointsItem.
        :type: str
        """
        allowed_values = ["Monthly", "Weekly", "Daily"]
        if granularity_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for granularity_type -> " + granularity_type)
            self._granularity_type = "outdated_sdk_version"
        else:
            self._granularity_type = granularity_type

    @property
    def points(self):
        """
        Gets the points of this UserBestPointsItem.
        Gamification points

        :return: The points of this UserBestPointsItem.
        :rtype: int
        """
        return self._points

    @points.setter
    def points(self, points):
        """
        Sets the points of this UserBestPointsItem.
        Gamification points

        :param points: The points of this UserBestPointsItem.
        :type: int
        """
        
        self._points = points

    @property
    def date_start_workday(self):
        """
        Gets the date_start_workday of this UserBestPointsItem.
        Start workday of the best points aggregation interval. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :return: The date_start_workday of this UserBestPointsItem.
        :rtype: date
        """
        return self._date_start_workday

    @date_start_workday.setter
    def date_start_workday(self, date_start_workday):
        """
        Sets the date_start_workday of this UserBestPointsItem.
        Start workday of the best points aggregation interval. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :param date_start_workday: The date_start_workday of this UserBestPointsItem.
        :type: date
        """
        
        self._date_start_workday = date_start_workday

    @property
    def date_end_workday(self):
        """
        Gets the date_end_workday of this UserBestPointsItem.
        End workday of the best points aggregation interval. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :return: The date_end_workday of this UserBestPointsItem.
        :rtype: date
        """
        return self._date_end_workday

    @date_end_workday.setter
    def date_end_workday(self, date_end_workday):
        """
        Sets the date_end_workday of this UserBestPointsItem.
        End workday of the best points aggregation interval. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :param date_end_workday: The date_end_workday of this UserBestPointsItem.
        :type: date
        """
        
        self._date_end_workday = date_end_workday

    @property
    def rank(self):
        """
        Gets the rank of this UserBestPointsItem.
        The rank of this user

        :return: The rank of this UserBestPointsItem.
        :rtype: int
        """
        return self._rank

    @rank.setter
    def rank(self, rank):
        """
        Sets the rank of this UserBestPointsItem.
        The rank of this user

        :param rank: The rank of this UserBestPointsItem.
        :type: int
        """
        
        self._rank = rank

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

